@@ -17,9 +17,11 @@ from schema_markdown import encode_query_string
 
 # The map of static file extension to content-type
 STATIC_EXT_TO_CONTENT_TYPE = {
+    '.csv': 'text/csv',
     '.gif': 'image/gif',
     '.jpeg': 'image/jpeg',
     '.jpg': 'image/jpeg',
+    '.json': 'application/json',
     '.markdown': 'text/markdown; charset=utf-8',
     '.md': 'text/markdown; charset=utf-8',
     '.png': 'image/png',
@@ -28,6 +30,7 @@ STATIC_EXT_TO_CONTENT_TYPE = {
     '.tiff': 'image/tiff',
     '.webp': 'image/webp'
 }
+MARKDOWN_EXTS = ('.md', '.markdown')
 
 
 class MarkdownUpApplication(chisel.Application):
@@ -138,7 +141,7 @@ def markdown_up_index(ctx, req):
     for entry in os.scandir(path):
         if entry.is_dir() and not entry.name.startswith('.'):
             directories.append(entry.name)
-        elif entry.is_file() and entry.name.endswith(('.md', '.markdown')):
+        elif entry.is_file() and entry.name.endswith(MARKDOWN_EXTS):
             files.append(entry.name)
 
     # Build the index markdown response
